def add(x, y):
	""" calculates sum of x and y.
	Parameters:
		x (int): a number
		y (int): another number
	Returns:
		int: sum of x and y
	"""
	return x + y

def subtract(x , y):
	""" calculates difference of x and y.
	Parameters:
		x (int): a number
		y (int): another number
	Returns:
		int: difference of x and y
	"""
	return x - y

def multiply(x, y):
	""" calculates multiplication of x and y.
	Parameters:
		x (int): a number
		y (int): another number
	Returns:
		int: multiplication of x and y
	"""
	return x * y

def divide(x , y):
	""" calculates division of x and y.
	Parameters:
		x (int): a number
		y (int): another number
	Returns:
		int: division of x and y
	"""
	return x / y

